# recon3d

[![userguide][userguide_badge]](https://sandialabs.github.io/recon3d/docs/userguide/book/index.html) [![api][api_badge]](https://sandialabs.github.io/recon3d/docs/api/index.html) [![test-coverage][test-coverage_badge]](https://sandialabs.github.io/recon3d/coverage_reports/htmlcov/index.html) [![lint][lint_badge]](https://sandialabs.github.io/recon3d/logs/lint.log) [![version][version_badge]](https://github.com/sandialabs/recon3d) 

[userguide_badge]: https://sandialabs.github.io/recon3d/badges/userguide.svg
[api_badge]: https://sandialabs.github.io/recon3d/badges/api.svg
[test-coverage_badge]: https://sandialabs.github.io/recon3d/badges/test-coverage.svg
[lint_badge]: https://sandialabs.github.io/recon3d/badges/lint.svg
[version_badge]: https://sandialabs.github.io/recon3d/badges/version.svg

## Getting Started

Installation instructions and more can be found in the [User Guide](https://sandialabs.github.io/recon3d/docs/userguide/book/index.html).

More info coming soon!
